==> zio-aws-route53recoverycontrolconfig_3-5.17.129.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteSafetyRuleRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteSafetyRuleRequest(safetyRuleArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest = {
    import DeleteSafetyRuleRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
      .builder()
      .safetyRuleArn(__string.unwrap(safetyRuleArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
      .wrap(buildAwsValue())
}
object DeleteSafetyRuleRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteSafetyRuleRequest(safetyRuleArn)
    def safetyRuleArn: __string
    def getSafetyRuleArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(safetyRuleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest.ReadOnly {
    override val safetyRuleArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.safetyRuleArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-6.20.78.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteSafetyRuleRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteSafetyRuleRequest(safetyRuleArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest = {
    import DeleteSafetyRuleRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
      .builder()
      .safetyRuleArn(safetyRuleArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
      .wrap(buildAwsValue())
}
object DeleteSafetyRuleRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteSafetyRuleRequest(safetyRuleArn)
    def safetyRuleArn: __string
    def getSafetyRuleArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(safetyRuleArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest.ReadOnly {
    override val safetyRuleArn: __string = impl.safetyRuleArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteSafetyRuleRequest.ReadOnly =
    new Wrapper(impl)
}
